#[non_exhaustive]pub enum EncoderState {
EncodingReset,
EncodingComplete,
EncodingMemoryFull,
}Expand description
RMT encoding state
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EncodingReset
The encoding session is in reset state
EncodingComplete
The encoding session is finished, the caller can continue with subsequent encoding
EncodingMemoryFull
The encoding artifact memory is full, the caller should return from current encoding session.