pub fn into_raw<E: Encoder>(encoder: E) -> EncoderWrapper<E>Expand description
A helper function to convert a custom RMT encoder into a raw encoder that can be used by the RMT driver.
Panics
If the allocation for the encoder wrapper fails.
pub fn into_raw<E: Encoder>(encoder: E) -> EncoderWrapper<E>A helper function to convert a custom RMT encoder into a raw encoder that can be used by the RMT driver.
If the allocation for the encoder wrapper fails.