EncoderWrapper

Struct EncoderWrapper 

pub struct EncoderWrapper<E>(/* private fields */);
A type implementing Encoder can not be directly used by the driver, because the driver expects a different interface (see RawEncoder).

This type adapts an Encoder to a RawEncoder, taking care of the unsafe parts.

Implementations

Source

impl<E: Encoder> EncoderWrapper<E>

pub fn new(encoder: E) -> Result<Self, EspError>