RmtChannelHandle

Struct RmtChannelHandle 

pub struct RmtChannelHandle { /* private fields */ }
A handle to an RMT channel.

For the special encoders like CopyEncoder or BytesEncoder that directly write to the RMT memory, this handle is used to access the channel.

For third-party encoders this functionality is not exposed. To prevent misuse, this type wraps the raw handle and does not expose it.