pub struct BytesEncoder { /* private fields */ }Expand description
An encoder that dynamically encodes a user space byte stream into RMT symbols.
It is usually used to encode dynamic data, e.g., the address and command fields in the IR protocol.
Implementations
Sourceimpl BytesEncoder
impl BytesEncoder
Sourcepub fn new() -> Result<Self, EspError>
pub fn new() -> Result<Self, EspError>
Constructs a new bytes encoder with default configuration.
Sourcepub fn with_config(config: &BytesEncoderConfig) -> Result<Self, EspError>
pub fn with_config(config: &BytesEncoderConfig) -> Result<Self, EspError>
Constructs a new bytes encoder with the provided configuration.