pub struct CopyEncoder { /* private fields */ }Expand description
A copy encoder copies the provided symbols from the user space into the driver layer.
It is usually used to encode non-mut data, i.e. data that does not change at runtime
after initialization, such as the leading code in the IR protocol.
For custom Encoder this type is essential to
copy the generated symbols into the RMT driver.
Implementations
Sourceimpl CopyEncoder
impl CopyEncoder
Sourcepub fn new() -> Result<Self, EspError>
pub fn new() -> Result<Self, EspError>
Constructs a new copy encoder with default configuration.
Sourcepub fn with_config(config: &rmt_copy_encoder_config_t) -> Result<Self, EspError>
pub fn with_config(config: &rmt_copy_encoder_config_t) -> Result<Self, EspError>
Constructs a new copy encoder with the provided configuration.