Struct RmtChannelHandle
Source pub struct RmtChannelHandle { }
A handle to an RMT channel.
For the special encoders like CopyEncoder or BytesEncoder that
directly write to the RMT memory, this handle is used to access the channel.
For third-party encoders this functionality is not exposed. To prevent misuse,
this type wraps the raw handle and does not expose it.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.